%% Import table of CTD based data
% Use ImportData_TS.m to import your CTD data table into MATLAB
%
% The MATLAB script createse a temperature- and a salinity-table from CTD 
% data or from additional used sensors including date and time.
% It automatically creates following variables: 
%    -	sampleSalinity.mat
%    -	sampleTemperature.mat
%    -	DateTime.mat
%    -	NitrateWetChem.mat
% Keep variables (mat-files) within your workspace.
% Before running the CalculateNO3 script these variables have to
% be in your workspace!


%% Import AscII file
TS_list = dir('TS_*.txt'); %ADAPT filename!
TS_k = size(TS_list);

delimiter = '\t';
headerlines = 1;

A = importdata(TS_list(1).name, delimiter, headerlines);

Raw_DateTime = A.textdata(2:end,1);
Raw_TS = A.data;


%% Convert imported data into variables
DateTime = Raw_DateTime;
sampleSalinity = Raw_TS(:,1);
sampleTemperature = Raw_TS(:, 2);
NitrateWetChem = Raw_TS(:, 3);


%% Clear temporary variables
clearvars A TS_list TS_k delimiter headerlines Raw_DateTime Raw_TS


%% Save variables
save('sampleSalinity.mat','sampleSalinity')
save('sampleTemperature.mat','sampleTemperature')
save('NitrateWetChem.mat','NitrateWetChem')
save('DateTime.mat','DateTime')

